@@ -15,11 +15,6 @@ class Options;
 class States;
 class Block;
 
-namespace FBB
-{
-    class Arg;
-}
-
 class Generator
 {
     enum
@@ -51,7 +46,6 @@ class Generator
     typedef std::vector<Pair> PVector;
 
     Options &d_options;
-    FBB::Arg &d_arg;
     Rules const &d_rules;
     Ranges const &d_ranges;
     DFAs const &d_dfas;
@@ -96,12 +90,13 @@ class Generator
                                       size_t offset);
 
         void actions(std::ostream &out) const;
-        void tailCount(std::ostream &out) const;
         void baseClassH(std::ostream &out) const;
         void baseIncludes(std::ostream &out) const;
+        void caseCheck(std::ostream &out) const;
         void classH(std::ostream &out) const;
         void classHead(std::ostream &out) const;
         void classIH(std::ostream &out) const;
+        bool debugCodeRequired() const;
         void debug(std::ostream &out) const;
         void debugDecl(std::ostream &out) const;
         void debugFunctions(std::ostream &out) const;
@@ -124,6 +119,7 @@ class Generator
         void ranges(std::ostream &out) const;
         void scannerConstructors(std::ostream &out) const;
         void startCondNames(std::ostream &out) const;
+        void tailCount(std::ostream &out) const;
 
         size_t dfaCols() const;
 
