@@ -41,9 +41,6 @@ void Options::setAccessorVariables()
     if (!arg.option(&d_lexSkeleton, 'L'))
         d_lexSkeleton            = d_skeletonDirectory + FLEXCPP_CC;
 
-    if (arg.option(0, "interactive")) // does not overwrite %option when no
-        d_interactive = true;         // --interactive is supplied
-
     // Paths
 
     bool targetDirOption = arg.option(&d_targetDirectory, "target-directory");
